# Examples of using pid4cat-model

This folder contains some example data and scripts (Python & jupyter notebooks).
There are examples for using the data model as well as for making API requests.

The JSON and YAML files in this directory were created by running the example scripts.

However, the the data in subfolder [/output](/output) are created by running the command `just test`,
which includes a step to generate different representations of the data in [tests/data](../tests/data/).
It also generates a markdown documentation of the examples which is not very useful in its current form.
Hence, the `output` sub-folder is git-ignored.
